Authors
=======

Contributors to Mopidy in the order of appearance:

- Stein Magnus Jodal <stein.magnus@jodal.no>
- Johannes Knutsen <johannes@knutseninfo.no>
- Thomas Adamcik <adamcik@samfundet.no>
- Kristian Klette <klette@klette.us>

Also, we would like to thank:

- Jørgen P. Tjernø for his work on the Python wrapper for Despotify.
- Doug Winter for his work on the Python wrapper for libspotify.
